function f = cost_CTLS(x,ith_row,C_mat,num_state,num_data,num_exp)
% Cost function for the constraint total least squares algorithm (CTLS)
%
% Control & Instrumentation Group
% Department of Engineering
% University of Leicester, Leicester, UK
%
% Programmed by Jongrae Kim <jrk7@le.ac.uk>
% 8th May 2006


i = ith_row;
n = num_state;
L = num_data;
p = num_exp;

ei = zeros(n,1);
ei(i) = 1;

x = x(:);

Big_Hx = zeros(p*(L-1),p*n*L);
Big_Hx = sparse(Big_Hx);

for idx=1:num_state    
    % Gi from i=1 to i=n
    Gi = [kron(eye(L-1),ei)' zeros(L-1,n)];
    Gi = sparse(Gi);
    
    % Gi for multiple experiments from i=1 to i=n
    Big_Gi = kron(eye(p),Gi);
    Big_Hx = Big_Hx + x(idx)*Big_Gi;        
end

% G_{n+2}
G_n_plus_2 = [zeros(L-1,n) kron(eye(L-1),ei)'];
G_n_plus_2 = sparse(G_n_plus_2);

% G_{n+2} for multiple experiments
Big_G_n_plus_2 = kron(eye(p),G_n_plus_2);

% Hx for multiple experiments
Big_Hx = Big_Hx - Big_G_n_plus_2;

% cost
f = [x' -1]*C_mat'/(Big_Hx*Big_Hx')*C_mat*[x; -1];